pub struct IncrementalState {
pub files: HashMap<PathBuf, FileState>,
}Expand description
The incremental state, tracking which files have been indexed.
Fields
files: HashMap<PathBuf, FileState>Map from file path to its last indexed state.
Implementations
Sourceimpl IncrementalState
impl IncrementalState
Sourcepub fn load(path: &Path) -> Result<Self, IndexError>
pub fn load(path: &Path) -> Result<Self, IndexError>
Load incremental state from disk.
Sourcepub fn detect_changes(&self, current_files: &[PathBuf]) -> FileChanges
pub fn detect_changes(&self, current_files: &[PathBuf]) -> FileChanges
Detect changes between the current file system state and the last index.
Sourcepub fn update_file(
&mut self,
path: PathBuf,
content: &[u8],
chunk_ids: Vec<u64>,
)
pub fn update_file( &mut self, path: PathBuf, content: &[u8], chunk_ids: Vec<u64>, )
Update the state for a file that has been indexed.
Sourcepub fn remove_file(&mut self, path: &Path) -> Option<FileState>
pub fn remove_file(&mut self, path: &Path) -> Option<FileState>
Remove a file from the incremental state.
Sourcepub fn chunk_ids_for_file(&self, path: &Path) -> Vec<u64>
pub fn chunk_ids_for_file(&self, path: &Path) -> Vec<u64>
Get chunk IDs associated with a file.
Sourcepub fn chunk_ids_to_remove(&self, deleted_files: &[PathBuf]) -> Vec<u64>
pub fn chunk_ids_to_remove(&self, deleted_files: &[PathBuf]) -> Vec<u64>
Get all chunk IDs from deleted files.
Sourcepub fn apply_deletions(&mut self, deleted_files: &[PathBuf]) -> Vec<u64>
pub fn apply_deletions(&mut self, deleted_files: &[PathBuf]) -> Vec<u64>
Merge changes: remove deleted file entries, return IDs to remove from index.