Tree-sitter integration.
Uses individual tree-sitter language crates to parse source files into ASTs. Supports language detection by file extension and AST traversal.
Enums
- Supported
Language - Supported languages and their Tree-sitter grammars.
Functions
- create_
parser - Create a parser configured for the given language.
- parse_
source - Parse source code with the given language and return the tree.