pub fn parse_source(
source: &str,
lang: SupportedLanguage,
) -> Result<Tree, ParserError>Expand description
Parse source code with the given language and return the tree.
pub fn parse_source(
source: &str,
lang: SupportedLanguage,
) -> Result<Tree, ParserError>Parse source code with the given language and return the tree.