File filter module.
Provides binary file detection, file size limits, and file type whitelist/blacklist filtering.
Functions
- is_
binary_ content - Check if content appears to be binary.
- is_
binary_ file - Check if a file is likely a binary file by examining its content.
- is_
source_ file - Check if a file has a recognized source code extension.
- should_
index_ file - Check if a file should be included for indexing.