pub struct FileWatcher { /* private fields */ }Expand description
A file watcher that monitors a directory tree for changes.
Implementations
Sourceimpl FileWatcher
impl FileWatcher
Sourcepub fn new(watch_path: &Path) -> Result<Self, ScannerError>
pub fn new(watch_path: &Path) -> Result<Self, ScannerError>
Create a new file watcher for the given directory.
Starts watching recursively. File events can be received
via the recv method.
Sourcepub fn recv(&self) -> Option<FileEvent>
pub fn recv(&self) -> Option<FileEvent>
Receive the next file event, blocking until one is available.
Sourcepub fn drain_events(&self) -> Vec<FileEvent>
pub fn drain_events(&self) -> Vec<FileEvent>
Drain all pending events (non-blocking).
Sourcepub fn recv_timeout(&self, timeout: Duration) -> Option<FileEvent>
pub fn recv_timeout(&self, timeout: Duration) -> Option<FileEvent>
Receive with timeout.