pub fn start_async_watcher(
watch_path: &Path,
) -> Result<(RecommendedWatcher, UnboundedReceiver<FileEvent>), ScannerError>Expand description
Create an async watcher that sends events through a tokio channel.
This is useful for integration with the async Daemon mode.